@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use parent 'Net::Hadoop::WebHDFS';
 
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 use LWP::UserAgent;
 use Carp;
@@ -24,7 +24,13 @@ sub new {
     delete $self->{furl};
     $self->{debug} = $debug;
 
-    $self->{ua} = LWP::UserAgent->new;
+    my %ua_opts;
+    for my $passthru_opt (qw/ env_proxy proxy no_proxy /) {
+        $ua_opts{$passthru_opt} = $options{$passthru_opt}
+            if ( exists $options{$passthru_opt} );
+    }
+
+    $self->{ua} = LWP::UserAgent->new( %ua_opts );
     $self->{ua}->agent("Net::Hadoop::WebHDFS::LWP " . $class->VERSION );
     $self->{useragent} = $self->{ua}->agent;
 
@@ -160,7 +166,7 @@ Net::Hadoop::WebHDFS::LWP - Client library for Hadoop WebHDFS and HttpFs, with K
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
